cd src
for i in TelAviv DeadSea Jerusalem OldJaffa Shalomsc Shalomst
do
for s in 0 0.5 1 2 3 4 5
do
../../../../tools/make1mffont $i $s
../../../../tools/make1mffont $i"_newcode" $s
done
done
for i in TelAviv DeadSea Jerusalem OldJaffa
do
for x in 0.6 0.7 0.8 0.9
do
cmmf "\mode=localfont; mag="$x";" input $i
gftopk $i.*gf
mv $i.tfm ../tfm
gftopk $i.*gf
mv $i.*pk ../pk
rm $i.*gf $i.log
done
done
cmmf "\mode=localfont; mag=0.75;" input Jerusalem
gftopk Jerusalem.*gf
mv Jerusalem.tfm ../tfm
gftopk Jerusalem.*gf
mv Jerusalem.*pk ../p
rm Jerusalem.*gf Jerusalem.log
../../../../tools/makemffont hclassic
../../../../tools/makemffont hcaption
for i in 10 12 17 7 8 9 s10 s12 s8 s9 bx10
do
../../../../tools/make1mffont redis$i 0
../../../../tools/make1mffont "redis"$i"_newcode" 0
done
cd ..




